@@ -23,7 +23,6 @@
 
 #include "mixgtk_wm.h"
 
-#include "mixgtk_widgets.h"
 #include "mixgtk_config.h"
 #include "mixgtk_device.h"
 #include "mixgtk_mixvm.h"
@@ -53,6 +52,9 @@ static GtkContainer *mixvm_container_ = NULL;
 static GtkContainer *mixal_container_ = NULL;
 static GtkContainer *dev_container_ = NULL;
 
+static GtkToolItem *attach_button_ = NULL;
+static GtkToolItem *detach_button_ = NULL;
+
 static const gchar *TB_MENU_NAME_ = "show_toolbars";
 static GtkCheckMenuItem *tb_menu_ = NULL;
 static GtkNotebook *notebook_ = NULL;
@@ -78,6 +80,8 @@ static void mixal_attach_ (void);
 static void mixal_detach_ (void);
 static void dev_attach_ (void);
 static void dev_detach_ (void);
+static void update_attach_buttons_ (void);
+static void on_tb_style_ (GtkMenuItem *w, gpointer style);
 static void on_nb_switch_ (GtkNotebook *notebook, GtkWidget *page,
                            guint page_num, gpointer user_data);
 
@@ -104,6 +108,7 @@ mixgtk_wm_init (void)
   init_mixvm_ ();
   init_mixal_ ();
   init_dev_ ();
+  init_tb_ ();
 
   for (k = 0; k < INF_NO_; ++k)
     {
@@ -113,7 +118,6 @@ mixgtk_wm_init (void)
         mixgtk_wm_attach_window (k);
     }
 
-  init_tb_ ();
   init_about_ ();
   init_autosave_ ();
   init_visibility_ ();
@@ -135,6 +139,7 @@ mixgtk_wm_detach_window (mixgtk_window_id_t w)
       if (gtk_notebook_get_n_pages (notebook_) < 1)
         gtk_widget_hide (GTK_WIDGET (notebook_));
       gtk_widget_show (mixgtk_widget_factory_get_dialog (infos_[w].dialog));
+      update_attach_buttons_ ();
     }
 }
 
@@ -154,6 +159,7 @@ mixgtk_wm_attach_window (mixgtk_window_id_t w)
       mixgtk_config_update (infos_[w].config_key, DETACH_NO_);
       if (gtk_notebook_get_n_pages (notebook_) == 1)
         gtk_widget_show (GTK_WIDGET (notebook_));
+      update_attach_buttons_ ();
     }
 }
 
@@ -218,7 +224,6 @@ on_widget_attach (GtkWidget *ign, gpointer id)
   mixgtk_wm_attach_window (GPOINTER_TO_INT (id));
 }
 
-
 /* about box */
 void
 on_about_activate (GtkWidget *w, gpointer data)
@@ -227,6 +232,13 @@ on_about_activate (GtkWidget *w, gpointer data)
   gtk_widget_show (about_);
 }
 
+void
+on_about_clicked (GtkWidget *w)
+{
+  if (about_) gtk_widget_hide (about_);
+}
+
+
 
 static void
 init_info_ (void)
@@ -426,6 +438,10 @@ init_dev_ (void)
 static void
 init_tb_ (void)
 {
+  gchar *names[4];
+  gint k;
+  gint tb_style = mixgtk_config_tb_style ();
+
   tb_menu_ = GTK_CHECK_MENU_ITEM
     (mixgtk_widget_factory_get_child_by_name (MIXGTK_MAIN,
   					      TB_MENU_NAME_));
@@ -436,6 +452,55 @@ init_tb_ (void)
 
   g_signal_connect (G_OBJECT (tb_menu_), "toggled",
                     G_CALLBACK (on_show_toolbars_toggled), NULL);
+
+  attach_button_ = GTK_TOOL_ITEM
+    (mixgtk_widget_factory_get (MIXGTK_MAIN, MIXGTK_WIDGET_ATTACH_BUTTON));
+  detach_button_ = GTK_TOOL_ITEM
+    (mixgtk_widget_factory_get (MIXGTK_MAIN, MIXGTK_WIDGET_DETACH_BUTTON));
+
+  g_assert (attach_button_);
+  g_assert (detach_button_);
+
+  names[GTK_TOOLBAR_ICONS] = "tb_style_icons";
+  names[GTK_TOOLBAR_TEXT] = "tb_style_labels";
+  names[GTK_TOOLBAR_BOTH] = "tb_style_both";
+  names[GTK_TOOLBAR_BOTH_HORIZ] = "tb_style_bothh";
+
+  for (k = 0; k < 4; ++k)
+    {
+      GtkWidget *item =
+        mixgtk_widget_factory_get_child_by_name (MIXGTK_MAIN, names[k]);
+      g_signal_connect (G_OBJECT (item),
+                        "activate",
+                        G_CALLBACK (on_tb_style_), GUINT_TO_POINTER (k));
+      if (k == tb_style)
+        {
+          gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item), TRUE);
+        }
+    }
+}
+
+static void
+on_tb_style_ (GtkMenuItem *w, gpointer style)
+{
+  static const gchar *TB_NAME = "main_toolbar";
+  static const gchar *TB_DNAME = "dlg_toolbar";
+
+  guint ui_style = GPOINTER_TO_UINT (style);
+  gint k;
+
+  GtkToolbar *tb = GTK_TOOLBAR
+    (mixgtk_widget_factory_get_child_by_name (MIXGTK_MAIN, TB_NAME));
+  gtk_toolbar_set_style (tb, ui_style);
+
+  for (k = 0; k < INF_NO_; ++k)
+    {
+      GtkToolbar *tb = GTK_TOOLBAR
+        (mixgtk_widget_factory_get_child_by_name (infos_[k].dialog, TB_DNAME));
+      gtk_toolbar_set_style (tb, ui_style);
+    }
+
+  mixgtk_config_set_tb_style (ui_style);
 }
 
 static void
@@ -443,7 +508,7 @@ show_toolbars_ (gboolean show)
 {
   static const gchar *HANDLE_NAME = "tb_handle";
 
-  int k;
+  gint k;
 
   GtkWidget *handle =
     mixgtk_widget_factory_get_child_by_name (MIXGTK_MAIN, HANDLE_NAME);
@@ -568,4 +633,27 @@ on_nb_switch_ (GtkNotebook *notebook, GtkWidget *page,
     mixgtk_mixal_pop_status ();
 }
 
+static void
+update_attach_buttons_ (void)
+{
+  gint k;
+  gboolean wants_attach = FALSE;
+  gboolean wants_detach = FALSE;
+
+  g_assert (attach_button_);
+  g_assert (detach_button_);
+
+  for (k = 0; k < INF_NO_; ++k)
+    {
+      wants_attach = wants_attach || infos_[k].detached;
+      wants_detach = wants_detach || !infos_[k].detached;
+    }
+
+  gtk_tool_item_set_visible_horizontal (attach_button_, wants_attach);
+  gtk_tool_item_set_visible_vertical (attach_button_, wants_attach);
+  gtk_tool_item_set_visible_horizontal (detach_button_, wants_detach);
+  gtk_tool_item_set_visible_vertical (detach_button_, wants_detach);
+}
+
+
 
